@@ -1,12 +1,13 @@
-# pylint: disable=missing-module-docstring
+"brreg api"
 # pylint: disable=line-too-long
+import logging
 from typing import Generator
 from datetime import datetime
 import gzip
 import requests # type: ignore
 import ijson # type: ignore
 from dwh_oppfolging.misc.transforms import dict_to_string, string_to_sha256_hash, string_to_naive_norwegian_datetime
-from dwh_oppfolging.apis.brreg_api_v1_structs import PagedRequestForEmbeddedList, Update
+from dwh_oppfolging.apis.brreg_api_v1_types import PagedRequestForEmbeddedList, Update
 
 
 API_VERSION = 1
@@ -92,7 +93,7 @@ def _get_unit_record_from_update_batch(orgnr_update_lkp: dict[str, Update], unit
     return orgnr_record_lkp
 
 
-def get_latest_records_for_unit(download_date: datetime, last_modified_date: datetime, unit_name: str, page_size=500):
+def get_latest_records_for_unit(download_date: datetime, last_modified_date: datetime, unit_name: str, page_size=500) -> Generator[list, None, None]:
     """params:
         last_modified_date: smallest update date
         unit_name: enheter | undereneheter
@@ -110,8 +111,8 @@ def get_latest_records_for_unit(download_date: datetime, last_modified_date: dat
         old_length = len(orgnr_update_lkp)
         orgnr_record_lkp_batch = _get_unit_record_from_update_batch(orgnr_update_lkp, unit_name, download_date)
         new_length = len(orgnr_update_lkp)
-        print(f"found {old_length - new_length} of {old_length} orgs with batched search")
-        print("appending remaining using single requests")
+        logging.info(f"found {old_length - new_length} of {old_length} orgs with batched search")
+        logging.info("appending remaining using single requests")
         orgnr_record_lkp_batch |= {
             orgnr: _get_unit_record_from_update_single(update, unit_name, download_date)
             for orgnr, update in orgnr_update_lkp.items()
@@ -119,24 +120,25 @@ def get_latest_records_for_unit(download_date: datetime, last_modified_date: dat
 
         orgnr_record_lkp |= orgnr_record_lkp_batch
 
-    return list(orgnr_record_lkp.values())
+    yield list(orgnr_record_lkp.values())
 
 
 def stream_latest_records_for_unit_from_file(download_date: datetime, unit_name: str, batch_size: int = 1000) -> Generator[list, None, None]:
-    """yields [records] from large file
-        must be run some time after 5
+    """
+    yields [records] from large file, must be run some time after 5 brreg local time
+    useful for init loading table
     """
     assert datetime.today().hour > 5, "too early"
     updated_date_str = datetime.today().replace(hour=5, minute=0, second=0).isoformat(timespec="milliseconds")+"Z"
     url = _BASE_URL + "/" + unit_name + "/" + "lastned"
     headers = _build_headers(unit_name, "gzip")
-    print("requesting filestream from api")
+    logging.info("requesting filestream from api")
     with requests.get(url, headers=headers, proxies={}, stream=True, timeout=100) as response:
         response.raise_for_status()
-        print("decompressing filestream")
+        logging.info("decompressing filestream")
         with gzip.open(response.raw, "rb") as file:
             records = []
-            print("iterating over json objects")
+            logging.info("iterating over json objects")
             for record in ijson.items(file, "item"):  # type: ignore
                 records.append(
                     _build_unit_record(
