@@ -1,8 +1,10 @@
-# pylint: disable=missing-module-docstring
+"ssb api"
+
+import logging
 from datetime import datetime
 import requests # type: ignore
 from dwh_oppfolging.misc.transforms import dict_to_string, string_to_sha256_hash, string_to_naive_norwegian_datetime
-from dwh_oppfolging.apis.ssb_api_v1_structs import Version, Correspondence
+from dwh_oppfolging.apis.ssb_api_v1_types import Version, Correspondence
 
 API_VERSION = 1
 API_NAME = "SSB"
@@ -108,16 +110,9 @@ def _get_all_versions_for_classification(classification_id: int):
     versions = [_build_version_struct(entry) for entry in data["versions"]]
 
     if len(versions) == 0:
-        print("found no versions for classification", classification_id)
+        logging.info(f"found no versions for classification {classification_id}")
     else:
-        print(
-            "found version" + "s" * (len(versions) > 1),
-            ", ".join(str(version.version_id) for version in versions[:-1])
-            + (len(versions) > 1) * ", and "
-            + str(versions[-1].version_id),
-            "for classification",
-            classification_id,
-        )
+        logging.info(f"found versions {[v.version_id for v in versions]} for classification {classification_id}")
 
     return versions
 
@@ -136,16 +131,9 @@ def _get_all_correspondences_for_classification_version(version: Version):
     ]
 
     if len(corrs) == 0:
-        print("found no correspondences for version", version.version_id)
+        logging.info(f"found no correspondences for version {version.version_id}")
     else:
-        print(
-            "found correspondence between target version" + "s" * (len(corrs) > 1),
-            ", ".join(str(corr.target_version_id) for corr in corrs[:-1])
-            + (len(corrs) > 1) * ", and "
-            + str(corrs[-1].target_version_id),
-            "and source version",
-            version.version_id,
-        )
+        logging.info(f"found correspondence {[c.target_version_id for c in corrs]} for version {version.version_id}")
 
     return corrs
 
@@ -166,7 +154,7 @@ def _get_all_records_in_classification_version(
         )
         for code in data["classificationItems"]
     ]
-    print("found", len(records), "records for version", version.version_id)
+    logging.info(f"found {len(records)} records for version {version.version_id}")
     return records
 
 
@@ -194,48 +182,47 @@ def _get_all_records_in_correspondence(
 
 
 def get_latest_records_for_classification(
-    last_modified_date: datetime, download_date: datetime, classification_id: int
+    download_date: datetime,
+    last_modified_date: datetime,
+    classification_id: int
 ):
     """gets all codes with versions"""
-    records = []
     for version in _get_all_versions_for_classification(classification_id):
         if not version.last_modified > last_modified_date:
-            print("skipping too old version last modified on", version.last_modified)
+            logging.info(f"skipping too old version last modified on {version.last_modified}")
             continue
-        records += _get_all_records_in_classification_version(
-            classification_id, version, download_date
-        )
-    return records
+        yield _get_all_records_in_classification_version(classification_id, version, download_date)
+
 
 
 def get_latest_records_for_correspondance(
-    last_modified_date: datetime,
     download_date: datetime,
+    last_modified_date: datetime,
     source_classification_id: int,
     target_classification_id: int,
 ):
     """gets all corresponence codes with versions"""
-    records = []
 
-    print("looking for versions of source classification", source_classification_id)
+    logging.info(f"looking for versions of source classification {source_classification_id}")
     source_versions = _get_all_versions_for_classification(source_classification_id)
 
-    print("looking for versions of target classification", target_classification_id)
+    logging.info(f"looking for versions of target classification {target_classification_id}")
     target_versions = _get_all_versions_for_classification(target_classification_id)
     target_version_ids = set(targ.version_id for targ in target_versions)
 
     for src in source_versions:
         for corr in _get_all_correspondences_for_classification_version(src):
             if not corr.target_version_id in target_version_ids:
-                print("skipping correspondence to unknown target classification")
+                logging.info("skipping correspondence to unknown target classification")
                 continue
             if not corr.last_modified > last_modified_date:
-                print(
-                    "skipping too old correspondence last modified on",
-                    corr.last_modified,
+                logging.info(
+                    f"skipping too old correspondence last modified on {corr.last_modified}",
                 )
                 continue
-            records += _get_all_records_in_correspondence(
-                source_classification_id, target_classification_id, corr, download_date
-            )
-    return records
+            yield _get_all_records_in_correspondence(
+                source_classification_id,
+                target_classification_id,
+                corr,
+                download_date
+                )
